gracetools.GraceContainer
=========================

.. abjad-lineage:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer

.. autoclass:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.descendants
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.leaves
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.lineage
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.music
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.override
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.parent
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.parentage
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.prolation
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.set
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.spanners
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.start_offset
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.storage_format
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.timespan
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.kind
   :noindex:

Methods
-------

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.append
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.detach
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.extend
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.index
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.insert
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.pop
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__add__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__call__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__ge__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__gt__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__iadd__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__imul__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__le__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__len__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__lt__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__mul__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__radd__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__rmul__
   :noindex:

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__setitem__
   :noindex:
